@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2010 Magic3 Project.
+ * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: static_contentDb.php 3104 2010-05-07 23:05:45Z fishbone $
+ * @version    SVN: $Id: static_contentDb.php 4690 2012-02-16 15:37:54Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -53,6 +53,20 @@ class static_contentDb extends BaseDb
 		$ret = $this->selectRecord($queryStr, $params, $row);
 		return $ret;
 	}
+	/**
+	 * コンテンツ項目をシリアル番号で取得
+	 *
+	 * @param string	$serial				シリアル番号
+	 * @param array     $row				レコード
+	 * @return bool							取得 = true, 取得なし= false
+	 */
+	function getContentBySerial($serial, &$row)
+	{
+		$queryStr  = 'SELECT * FROM content LEFT JOIN _login_user ON cn_create_user_id = lu_id AND lu_deleted = false ';
+		$queryStr .=   'WHERE cn_serial = ? ';
+		$ret = $this->selectRecord($queryStr, array($serial), $row);
+		return $ret;
+	}
 	/**
 	 * コンテンツ項目一覧を取得
 	 *
