@@ -1,13 +1,24 @@
 <?php
-// PukiWiki - Yet another WikiWikiWeb clone
-// $Id: pukiwiki.ini.php 1141 2008-10-27 06:10:58Z fishbone $
+/**
+ * PukiWiki用グローバル変数定義
+ *
+ * PHP versions 5
+ *
+ * LICENSE: This source file is licensed under the terms of the GNU General Public License.
+ *
+ * @package    Magic3 Framework
+ * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
+ * @copyright  Copyright 2006-2014 Magic3 Project.
+ * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
+ * @version    SVN: $Id: pukiwiki.ini.php 3478 2010-08-14 08:33:30Z fishbone $
+ * @link       http://www.magic3.org
+ */
 // Copyright (C)
 //   2002-2006 PukiWiki Developers Team
 //   2001-2002 Originally written by yu-ji
 // License: GPL v2 or (at your option) any later version
 //
 // PukiWiki main setting file
-// PukiWiki用グローバル変数		// add for Magic3 by naoki on 2008/10/6
 global $page_title;
 global $modifier;
 global $modifierlink;
@@ -76,6 +87,12 @@ global $line_break;
 global $usedatetime;
 global $agents;
 
+// Special
+//define('PKWK_READONLY',  1);
+if (!$gEnvManager->isSystemManageUser()) define('PKWK_SAFE_MODE', 1);			// システム運用者でない場合はセーフモードで立ち上げ
+//define('PKWK_OPTIMISE',  1);
+//define('TDIARY_THEME',   'digital_gadgets');
+
 /////////////////////////////////////////////////
 // Functionality settings
 
@@ -137,24 +154,26 @@ define('UI_LANG', LANG); // 'en' for Internationalized wikisite
 
 // You may hide these directories (from web browsers)
 // by setting DATA_HOME at index.php.
-
+/*
 define('DATA_DIR',      DATA_HOME . 'wiki/'     ); // Latest wiki texts
 define('DIFF_DIR',      DATA_HOME . 'diff/'     ); // Latest diffs
 define('BACKUP_DIR',    DATA_HOME . 'backup/'   ); // Backups
 define('CACHE_DIR',     DATA_HOME . 'cache/'    ); // Some sort of caches
-//define('UPLOAD_DIR',    DATA_HOME . 'attach/'   ); // Attached files and logs
-define('UPLOAD_DIR',    $gEnvManager->getCurrentWidgetRootPath() . '/upload/'); // Attached files and logs
+define('UPLOAD_DIR',    DATA_HOME . 'attach/'   ); // Attached files and logs
 define('COUNTER_DIR',   DATA_HOME . 'counter/'  ); // Counter plugin's counts
 define('TRACKBACK_DIR', DATA_HOME . 'trackback/'); // TrackBack logs
+define('PLUGIN_DIR',    DATA_HOME . 'plugin/'   ); // Plugin directory
+*/
 // modified for Magic3 by naoki on 2008/9/26
-//define('PLUGIN_DIR',    DATA_HOME . 'plugin/'   ); // Plugin directory
+//define('UPLOAD_DIR',    $gEnvManager->getCurrentWidgetRootPath() . '/upload/'); // Attached files and logs
+define('UPLOAD_DIR',    $gEnvManager->getResourcePath() . '/widgets/wiki/upload/');
 define('PLUGIN_DIR',    $gEnvManager->getCurrentWidgetIncludePath() . '/plugin/'); // Plugin directory
 
 /////////////////////////////////////////////////
 // Directory settings II (ended with '/')
 
 // Skins / Stylesheets
-define('SKIN_DIR', 'skin/');
+//define('SKIN_DIR', 'skin/');
 // Skin files (SKIN_DIR/*.skin.php) are needed at
 // ./DATAHOME/SKIN_DIR from index.php, but
 // CSSs(*.css) and JavaScripts(*.js) are needed at
@@ -203,18 +222,6 @@ $whatsdeleted = 'RecentDeleted'; // Removeed page list
 $interwiki    = 'InterWikiName'; // Set InterWiki definition here
 $menubar      = 'MenuBar';       // Menu
 
-/////////////////////////////////////////////////
-// Change default Document Type Definition
-
-// Some web browser's bug, and / or Java apprets may needs not-Strict DTD.
-// Some plugin (e.g. paint) set this PKWK_DTD_XHTML_1_0_TRANSITIONAL.
-
-//$pkwk_dtd = PKWK_DTD_XHTML_1_1; // Default
-//$pkwk_dtd = PKWK_DTD_XHTML_1_0_STRICT;
-//$pkwk_dtd = PKWK_DTD_XHTML_1_0_TRANSITIONAL;
-//$pkwk_dtd = PKWK_DTD_HTML_4_01_STRICT;
-//$pkwk_dtd = PKWK_DTD_HTML_4_01_TRANSITIONAL;
-
 /////////////////////////////////////////////////
 // Always output "nofollow,noindex" attribute
 
